#include <assert.h>
#include <stdio.h>
#include "aatree.h"

AANode *tree = AA_ROOT_NODE;
int next = 0;
const int list[] = { 10, 85, 15, 70, 20, 60, 30, 50, 65, 80, 90, 40, 5, 55, 35, 45 };

void emptyTest() {
	printf("The tree is ");
	if (AATreeIsEmpty(tree)) {
		printf("empty\n");
	}
	else {
		printf("not empty\n");
	}
}

void preorder(AANode *n) {
	printf("%i(%i) { ", n->key, n->level);
	if (n->left != AA_ROOT_NODE) {
		preorder(n->left);
	}
	else {
		printf("N ");
	}
	if (n->right != AA_ROOT_NODE) {
		preorder(n->right);
	}
	else {
		printf("N ");
	}
	printf("} ");
}

void detail(AANode *n) {
	AANode *items[32];
	int index = 0, len = 1;
	items[0] = n;
	while (len > 0) {
		n = items[index++ & 0x1F];
		len--;
		printf("%i(%i) ", n->key, n->level);
		if (n->left != AA_ROOT_NODE) {
			items[index + (len++ & 0x1F)] = n->left;
		}
		if (n->right != AA_ROOT_NODE) {
			items[index + (len++ & 0x1F)] = n->right;
		}
	}
}

int addNext(int index) {
	AANode *n;
	n = AATreeAdd(&tree, list[index]);
	if (n) {
		printf("Added %i to the tree\n", n->key);
		return n->key;
	}
	else {
		printf("Failed to add %i to the tree\n", n->key);
		return 0;
	}
}

int main() {
	int loop, key;
	emptyTest();
	loop = 0;
	do {
		if ((key = addNext(loop++)) == 0) return 1;
	} while (key != 35);
	preorder(tree);
	printf("\n");
	emptyTest();
	if (!addNext(loop++)) return 1;
	preorder(tree);
	printf("\n");
	emptyTest();
	
	loop = 0;
	do {
		AANode *n;
		n = AATreeFind(tree, key = list[loop++]);
		if (n->key == key) {
			printf("Found item %i in the tree\n", key);
		}
		else if (n != NULL) {
			printf("Incorrectly found item %i when searching for %i\n",
			n->key, key);
			return 2;
		}
		else {
			printf("Could not find item %i\n", key);
			return 3;
		}
	} while (key != 45);
	if (AATreeFind(tree, 42)) {
		printf("Found the answer that isn't there\n");
		return 4;
	}
	preorder(tree);
	printf("\n");
	loop = 0;
	while (!AATreeIsEmpty(tree)) {
		AANode *n;
		if (AATreeFind(tree, list[loop]) == NULL) {
			printf("Next key to remove, %i, is already gone\n", list[loop]);
			return 5;
		}
		if (list[loop] == 85) {
			printf("Problem is a spoon\n");
		}
		AATreeRemove(tree, list[loop]);
		preorder(tree);
		printf("\n");
		if (AATreeFind(tree, list[loop])) {
			printf("Failed to remove key %i\n", list[loop]);
			return 6;
		}
		loop++;
	}
	return 0;
}

