/**
 * @file color.c
 * Implementation of utility code to handle common colors and setting up device
 * specific color values.
 * @author Jeff Jackowski  (jeffj@ro.com)
 *
 * Copyright (C) 2007  Jeff Jackowski
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA. Or visit their website at: http://www.gnu.org/
 */

#include "color.h"
#include "render.h"

SDL_Color colorFmtInd[COLOR_MAX] = {
	{ 184, 50, 50, 255 },    // COLOR_RED
	{ 24, 26, 167, 255 },    // COLOR_BLUE
	{ 0, 160, 0, 255 },      // COLOR_GREEN
	{ 132, 0, 132, 255 },    // COLOR_PURPLE
	{ 0, 0, 0, 255 },        // COLOR_BLACK
	{ 255, 255, 255, 255 },  // COLOR_WHITE
	{ 183, 194, 95, 255 },   // COLOR_REGBACK
	{ 163, 57, 21, 255 },    // COLOR_PONGBACK
	{ 183, 194, 95, 255 },   // COLOR_BACK
	{ 128, 128, 128, 255 },  // COLOR_OBSTACLE
	{ 255, 255, 255, 127 }   // COLOR_TEXT
};

Uint32 colorVals[COLOR_MAX];

void SetupColorVals() {
	int loop;
	for (loop = 0; loop < COLOR_MAX; loop++) {
		colorVals[loop] = SDL_MapRGBA(dInfo.display->format,
		colorFmtInd[loop].r, colorFmtInd[loop].g, colorFmtInd[loop].b,
		colorFmtInd[loop].unused);
	}
}

Uint32 ColorBlend(SDL_Color c, SDL_Color d, int partsC, int partsD) {
	int r, g ,b, a;
	// blend all the parts together
	r = (partsC * c.r + partsD * d.r) / (partsC + partsD);
	g = (partsC * c.g + partsD * d.g) / (partsC + partsD);
	b = (partsC * c.b + partsD * d.b) / (partsC + partsD);
	a = (partsC * c.unused + partsD * d.unused) / (partsC + partsD);
	// find a close device specific color and return it
	return SDL_MapRGBA(dInfo.display->format, r, g, b, a);
}

