/**
 * @file color.h
 * Interface to utility code to handle common colors and setting up device
 * specific color values.
 * @author Jeff Jackowski  (jeffj@ro.com)
 *
 * Copyright (C) 2007  Jeff Jackowski
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA. Or visit their website at: http://www.gnu.org/
 */

#include <SDL.h>

/**
 * Indecies into an array of color values.
 */
enum {
	/**
	 * Display format independent color for the red team.
	 */
	COLOR_RED,
	/**
	 * Display format independent color for the blue team.
	 */
	COLOR_BLUE,
	/**
	 * Display format independent color for the green team.
	 */
	COLOR_GREEN,
	/**
	 * Display format independent color for the purple team.
	 */
	COLOR_PURPLE,
	/**
	 * Display format independent color for black.
	 */
	COLOR_BLACK,
	/**
	 * Display format independent color for white.
	 */
	COLOR_WHITE,
	/**
	 * Display format independent color for regular game background.
	 */
	COLOR_REGBACK,
	/**
	 * Display format independent color for pong tank background.
	 */
	COLOR_PONGBACK,
	/**
	 * Background.
	 */
	COLOR_BACK,
	/**
	 * Obstacle color.
	 */
	COLOR_OBSTACLE,
	/**
	 * Color for text messages.
	 */
	COLOR_TEXT,
	COLOR_MAX
};

/**
 * An array of display format indepenent colors.
 */
extern SDL_Color colorFmtInd[COLOR_MAX];

/**
 * An array of display specific color values.
 */
extern Uint32 colorVals[COLOR_MAX];

/**
 * Sets the values of ::colorVals to the corresponding closest color in the
 * current display surface's format. This function should be called whenever
 * the display format may have changed.
 * @author  Jeff Jackowski
 */
void SetupColorVals();

/**
 * Blends two device independent colors together and produces a device specific
 * result.
 * @code
 * color = ColorBlend(a, b, 2, 3); // color is 2/5 a and 3/5 b
 * @endcode
 * @param  a       One color to blend.
 * @param  b       Another color to blend.
 * @param  partsA  The number of times to count a.
 * @param  partsB  The number of times to count b.
 * @return The device specific color.
 * @author Jeff Jackowski
 */
Uint32 ColorBlend(SDL_Color a, SDL_Color b, int partsA, int partsB);

