/**
 * @file gamestate.h
 * Defines the functions used for STATE_CODES::STATE_PLAY.
 * @ingroup StatePlay
 * @author Jeff Jackowski  (jeffj@ro.com)
 *
 * Copyright (C) 2007  Jeff Jackowski
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA. Or visit their website at: http://www.gnu.org/
 */

#include "render.h"

/**
 * @defgroup StatePlay Gameplay State
 *
 * Runs the backbone of the gameplay code.
 *
 * @ingroup OperStates
 * @{
 */

/**
 * The background image. When its data pointer is set to NULL, the image has
 * not been loaded.
 */
extern RenderItem background;

/**
 * Initalizes the data needed for gameplay.
 * @return  True on sucess, false if there was an error.
 * @author  Jeff Jackowski
 */
int GameInit();

/**
 * Removes the data needed for gameplay and prepares the system to handle
 * another operating state.
 * @return  True on sucess, false if there was an error.
 * @author  Jeff Jackowski
 */
int GameUninit();

/**
 * Runs the body of the @ref GameSim.
 * @return  The next operating state.
 * @author  Jeff Jackowski
 */
int GameRun();

/** @} */
