/**
 * @file menustate.c
 * The implementation for STATE_CODES::STATE_MENUROOT.
 * @ingroup StateMenu
 * @author Jeff Jackowski  (jeffj@ro.com)
 *
 * Copyright (C) 2007  Jeff Jackowski
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA. Or visit their website at: http://www.gnu.org/
 */

#include "color.h"
#include "genconmac.h"
#include "menustate.h"
#include "netstat.h"
#include "states.h"
#include "teamsel.h"
#include <stdlib.h>

MenuSettings *menuSettings = NULL;

/**
 * The internal list of menu items used in the current menu.
 * @internal
 * @ingroup StateMenu
 */
static MenuItem *menu;

int MenuRootInit() {
	int loop;
	// set the text color
	colorFmtInd[COLOR_TEXT] = colorFmtInd[COLOR_BLACK];
	// get some memory and render text
	if (!(menuSettings = calloc(1, sizeof(MenuSettings))) ||
	!(menu = calloc(2, sizeof(MenuItem))) || !TextSetupStateMenu()) {
		// could not allocate the memory or text could not be prepared
		return STATE_ERROR;
	}
	// reset layer offsets
	for (loop = 0; loop < LAYER_MAX; loop++) {
		layers[loop].offX = layers[loop].offY = 0;
	}
	/**
	 * @todo  The following line of code should be in a function called when
	 *        the menu may need to go through a graphic reset sort of thing.
	 */
	// initialize menu items
	TeamSelInit(menu);
	if (!NetStatInit(menu + 1)) return STATE_ERROR;
	// initalize the menu
	SetupMenu(menu, 0, 2);
	return STATE_OK;
}

int MenuRootUninit() {
	NetStatUninit(menu + 1);
	TeamSelUninit(menu);
	RemoveMenu();
	free(menu);
	TextUnsetState();
	return STATE_OK;
}

