/**
 * @file name.h
 * Defines an interface to store and change the player's name. Intended to
 * be extended with a menu item for the user to change the name. 
 * @author Jeff Jackowski  (jeffj@ro.com)
 *
 * Copyright (C) 2007  Jeff Jackowski
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA. Or visit their website at: http://www.gnu.org/
 */

/**
 * Gets a copy of the local player's name. If the name has not already been
 * set by calling SetLocalPlayerName(), the user name stored in the environment
 * variables (USER on Unix-like systems, USERNAME on Windows) will be used.
 * @param dest  A pointer to where the name will be stored. The name will be
 *              no longer than ::MAX_NAME_LEN - 1 and will be null terminated.
 * @author  Jeff Jackowski
 */
void GetLocalPlayerName(rtsa_char *dest);

/**
 * Changes the local player's name to the given string.
 * @param name  A pointer to the string with the new name. Only the first
 *              ::MAX_NAME_LEN - 1 characters will be kept. If NULL or zero
 *              length, the user name stored in an environment variable (USER
 *              on Unix-like systems, USERNAME on Windows) will be set as the
 *              name. 
 * @author  Jeff Jackowski
 */
void SetLocalPlayerName(rtsa_char *name);

