/**
 * @file netstat.h
 * Defines an interface to the network status menu item.
 * @ingroup MenuNetStat
 * @author Jeff Jackowski  (jeffj@ro.com)
 *
 * Copyright (C) 2007  Jeff Jackowski
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA. Or visit their website at: http://www.gnu.org/
 */

#include "menu.h"

/**
 * @defgroup MenuNetStat Network Status Menu Item
 * Displays the current network status and provides a path to a network options
 * submenu.
 *
 * @ingroup MenuSys
 * @{
 */

/**
 * Sets up the network status menu item for use.
 * @note  There is no corresponding uninitalization function.
 * @author Jeff Jackowski
 */
Bool NetStatInit(MenuItem *item);

/**
 * Removes dynamically allocated data that is only needed by the network status
 * menu item while it is in use.
 * @param  item  A pointer to the item that represents the network status
 *               menu item.
 * @author Jeff Jackowski
 */
void NetStatUninit(MenuItem *item);

/**
 * Updates the network status item with new information and places its render
 * items in the appropriate spots.
 * @return  Always zero.
 * @author Jeff Jackowski
 */
int NetStatUpdate(MenuItem *item);

/**
 * Changes the network status item's display based on receiving or losing focus.
 * @author Jeff Jackowski
 */
void NetStatFocus(MenuItem *item);

/**
 * Responds to user input.
 * @return  ???
 * @author Jeff Jackowski
 */
int NetStatInput(MenuItem *item, Uint8 *ec, rtsa_char keyval);

/** @} */

