/**
 * @file player.c
 * Code for network transmission and reception of player data.
 * @author Jeff Jackowski  (jeffj@ro.com)
 *
 * Copyright (C) 2007  Jeff Jackowski
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA. Or visit their website at: http://www.gnu.org/
 */

#include "color.h"
#include "game.h"
#include "tanksprite.h"
#include <string.h>
#include <assert.h>


Uint32 localPlayer = 0;
Uint8  localUpdateFlags;

Player players[MAX_PLAYERS] = { 0 };

void AddPlayer(Player *p) {
	#ifdef MSG_DEBUG
	printf("Init player %d\n", p->pid);
	#endif
	assert(p->tank.renderer == NULL);
	assert(p->shell.renderer == NULL);
	// make the player active
	p->flags |= PLAYER_ACTIVE;
	p->deadTime = DEAD_TIME + 1;
	// create the required render items
	// start with the tank
	p->tank.loc.x = (p->x >> 8) * dInfo.luw;
	p->tank.loc.y = (p->y >> 8) * dInfo.luh;
	p->tank.loc.w = dInfo.luw * 8;
	p->tank.loc.h = dInfo.luh * 8;
	p->tank.renderer = DrawTank;
	AddRenderItem(&(p->tank), LAYER_TANKS);
	if (!(p->flags & PLAYER_DEAD)) {
		QueuePlaceTank(p->pid);
	}
	// add the shell
	p->shell.loc.w = dInfo.luw;
	p->shell.loc.h = dInfo.luh;
	p->shell.data = &(colorVals[p->team]);
	p->shell.renderer = SolidFillRenderer;
	AddRenderItem(&(p->shell), LAYER_TANKS);
	// check for an unset name
	if (p->name[0] == 0) {
		// set a default name
		rtsa_strcpy(p->name, strings[STRING_DEFAULTNAME]);
	}
	// render the player's name
	else if (TextRenderString(&(p->labelName), FONT_PLAYER, 0,
	colorFmtInd[COLOR_BLACK], p->name)) {
		// add the name
		AddRenderItem(&(p->labelName), LAYER_NAMES);
		if (dInfo.showLabels && !(p->flags & PLAYER_DEAD)) {
			PlacePlayerLabel(p);
		}
	}
}

void RemovePlayer(Player *p) {
	// see if the player is still active
	if (p->flags & PLAYER_ACTIVE) {
		// clear the player's render items
		ClearRenderItem(&(p->tank));
		// remove the player's render items
		RemoveRenderItem(&(p->tank));
		ClearRenderItem(&(p->shell));
		RemoveRenderItem(&(p->shell));
		// check for an existing name label
		if (p->labelName.renderer != NULL) {
			ClearRenderItem(&(p->labelName));
			RemoveRenderItem(&(p->labelName));
		}
		// get rid of any rendered text used for the player
		if (p->labelName.data) {
			SDL_FreeSurface(p->labelName.data);
		}
		/*
		if (p->largeName.data) {
			SDL_FreeSurface(p->largeName.data);
		}
		if (p->scoreText.data) {
			SDL_FreeSurface(p->scoreText.data);
		}
		*/
	}
	// clear out everything
	memset(p, 0, sizeof(Player));
	//p->flags = 0;
}
