/**
 * @file random.c
 * Abstracted interface to a random number generator.
 * @author Jeff Jackowski  (jeffj@ro.com)
 *
 * Copyright (C) 2007  Jeff Jackowski
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA. Or visit their website at: http://www.gnu.org/
 */

#include <stdlib.h>
#include <SDL.h>
#include <time.h>

#ifndef WIN32
/**
 * A file handle used to access a random number device run by the operating
 * system.
 */
static FILE *urand = NULL;
#endif                                                                       

void RandInit() {
 	#ifndef WIN32
	// see if /dev/urandom (pretty common on UNIX-like systems) has already
	// been opened, and if not, open it
	if ((urand == NULL) && ((urand = fopen("/dev/urandom", "rb")) == NULL))
	#endif
	{
		// couldn't open /dev/urandom, or on systen that doesn't support it
		srand((unsigned int)time(NULL));
	}
}

Uint32 RandNum() {
	#ifndef WIN32
	// check for already open file handle to /dev/urandom
	if (urand) {
		int num;
		// read in the next 4 bytes of randomness
		fread(&num, 4, 1, urand);
		return num;
	}
	#endif
	// use the ANSI C interface to a pseudo random number generator
	return (rand() << 16) | rand();
}

void RandUninit() {
	#ifndef WIN32
	// check for already open file handle to /dev/urandom
	if (urand) {
		// close the file
		fclose(urand);
	}
	#endif
}

