/**
 * @file teamsel.h
 * Defines an interface to the team selection menu item.
 * @ingroup MenuTeamSel
 * @author Jeff Jackowski  (jeffj@ro.com)
 *
 * Copyright (C) 2007  Jeff Jackowski
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA. Or visit their website at: http://www.gnu.org/
 */

#include "menu.h"

/**
 * @defgroup MenuTeamSel Team Selection Menu Item
 * Allows the user to select a team as designed in @ref MenuItemTeam.
 * The code expects only one team selction item to exist at any given time.
 *
 * @ingroup MenuSys
 * @{
 */

/**
 * Sets up the team selection menu item for use. Configures player data for the
 * display of two tanks.
 * @author  Jeff Jackowski
 */
void TeamSelInit(MenuItem *item);

/**
 * Cleans up what the team selection menu setup.
 * @author  Jeff Jackowski
 */
void TeamSelUninit(MenuItem *item);

/**
 * Updates the team selection item with new information and places its render
 * items in the appropriate spots.
 * @return  Always zero.
 * @author  Jeff Jackowski
 */
int TeamSelUpdate(MenuItem *item);

/**
 * Allows the player to chose a team using left, right, and fire inputs. The
 * selected team is stored in players[0].team.
 * @return  ::STATE_PLAY or zero.
 * @author  Jeff Jackowski
 */
int TeamSelInput(MenuItem *item, Uint8 *ec, rtsa_char keyval);

/** @} */

